# -*-coding: utf-8 -*-
# @Time    : 2023/4/7 01:09
# @Description  : 常用变量

# token file path
TOKEN_F_P = 'dp_tk.csv'
TOKEN_ERR_MSG = '请设置DouPand的token凭证码，如果没有请访问https://doupand.com注册申请'

# http url file path
URL_F_P = 'dp_url.csv'
